@@ -74,6 +74,11 @@ typedef enum {
 #define PK_PROVIDES_ENUM_PLASMA_SERVICE			(PK_PROVIDES_ENUM_POSTSCRIPT_DRIVER+1)
 #endif
 
+#if (!PK_CHECK_VERSION(0,7,2))
+#define PK_ROLE_ENUM_REPAIR_SYSTEM			(PK_ROLE_ENUM_UPGRADE_SYSTEM+1)
+#define PK_ROLE_ENUM_SIMULATE_REPAIR_SYSTEM		(PK_ROLE_ENUM_REPAIR_SYSTEM+1)
+#endif
+
 void		 gpk_enum_test				(gpointer	 data);
 const gchar	*gpk_role_enum_to_localised_past	(PkRoleEnum	 role)
 							 G_GNUC_CONST;
